summaryrefslogtreecommitdiff
path: root/src/mongo/db/keys_collection_client_direct.h
diff options
context:
space:
mode:
authorMisha Tyulenev <misha@mongodb.com>2019-06-20 14:20:31 -0400
committerMisha Tyulenev <misha@mongodb.com>2019-06-20 14:20:55 -0400
commit1d158cabb504fa9dba3ed0f0688cdf14cb7b0cba (patch)
treeea16bd71c9747040309a964246b743b9fa9b9bdf /src/mongo/db/keys_collection_client_direct.h
parent35424844fd9e10b042c435c83a8f1e23e42fb9e4 (diff)
downloadmongo-1d158cabb504fa9dba3ed0f0688cdf14cb7b0cba.tar.gz
SERVER-40535 read signing keys with readConcern level majority
Diffstat (limited to 'src/mongo/db/keys_collection_client_direct.h')
-rw-r--r--src/mongo/db/keys_collection_client_direct.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/mongo/db/keys_collection_client_direct.h b/src/mongo/db/keys_collection_client_direct.h
index 16aef9c7b73..9ad5dbb7490 100644
--- a/src/mongo/db/keys_collection_client_direct.h
+++ b/src/mongo/db/keys_collection_client_direct.h
@@ -46,10 +46,13 @@ class KeysCollectionClientDirect : public KeysCollectionClient {
public:
KeysCollectionClientDirect();
/**
* Returns keys for the given purpose and with an expiresAt value greater than newerThanThis.
*/
- StatusWith<std::vector<KeysCollectionDocument>> getNewKeys(
- OperationContext* opCtx, StringData purpose, const LogicalTime& newerThanThis) override;
+ StatusWith<std::vector<KeysCollectionDocument>> getNewKeys(OperationContext* opCtx,
+ StringData purpose,
+ const LogicalTime& newerThanThis,
+ bool useMajority) override;
/**
* Directly inserts a key document to the storage
@@ -46,10 +46,13 @@ class KeysCollectionClientDirect : public KeysCollectionClient {
KeysCollectionClientDirect();
/**
- * Returns keys for the given purpose and with an expiresAt value greater than newerThanThis.
+ * Returns keys for the given purpose and with an expiresAt value greater than newerThanThis,
+ * using readConcern level majority if possible.
*/